@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "roguel-ike" "0.1.3"
+(define-package "roguel-ike" "20241228.929"
   "Main file for roguel-ike."
   '((popup "0.5.0"))
   :url "https://github.com/stevenremot/roguel-ike"
